﻿//Locales for use. 'en' is necessary.
var LocaleList = ['en', 'ja', 'fr']
//Definition of Locale. If not defined, it depend on the OS Locale setting.
var Locale = 'en';
//Clock update interval [ms]
var UpdateInterval = 20000;
//Clock Font. If not defined, xx-small is used.
var fontSize = 'x-small';
//Dot size for the Clock Point.
var dotSize = 8;

//Time zone of the left end of the map.
var mapLeftTimeZone = -9;
//Hour span for the display(map) width
var mapTimeSpan = 22;

//DesktopEarth Settings
var DesktopEarth = new Object;
//EarthImage URI (must be same drive if IE8)
DesktopEarth.imgUri = '../../../../../AppData/Local/DesktopEarth/current.bmp';
//If it's DST now, make it true
DesktopEarth.dst = false;
//Setting of use DesktopEarth or not.
//If DesktopEarth is not installed, make it false.
DesktopEarth.use = true;
//Auto update DesktopEarth setting.
DesktopEarth.autoUpdate = false;

//If DesktopEarth.use is true, the following items can be overridden by the value in the Registory.
//Add black bars arround the image if needed / 0 or 1
DesktopEarth.blackBars = 0;
//Crop the image if needed / 0 or 1
DesktopEarth.crop = 1;
// Image Center On = +/-180[deg]
// 1000=Current Time Zone, 1001=Noon, 1002=Midnight, 1003=Sunset, 1004=Sunrise, 1006=Europ & Africa, 1007=Americas, 1008=Asia
DesktopEarth.centerOn = 1000;
//Map Update Interval
DesktopEarth.updateFreq = 3600000;

//Inner Frame
//URI
var InnerFrameHtml = '../calendar/calendar.html';
//X Alignment left, center or right
var InnerFrameXAlignment = 'center';
//X Position (px)
var InnerFrameX = 0;
//Width (px)
var InnerFrameWidth = 1000
//Y Alignment top, center or bottom
var InnerFrameYAlignment = 'top';
//Y Position (px)
var InnerFrameY = 0;
//Height (px)
var InnerFrameHeight = 70

/*
 * Cities Array
 *
 * Name      Display name for each locale
 * longitude Longitude of the City
 * latitude  Latitude of the City
 * LiftLabel none(false) = Name is next to dot, Clock is next line.
 *           true        = Clock is next to dot, Name is upper line.
 * OffsetUTC Hour difference from UTC at standard time
 * DLSrule Definition of DST kind. (ID of DLSrules array)
 *           '0' means No DST.
 */
var Cities =
[
	{
		Name		: {en: 'San Francisco', ja: 'サンフランシスコ', fr: 'San Francisco'},
		longitude	: -122.419,
		latitude	: 37.775,
		OffsetUTC	: -8,
		DLSrule	: 'US'
	},
	{
		Name		: {en: 'Minneapolis', ja: 'ミネアポリス', fr: 'Minneapolis'},
		longitude	: -93.264,
		latitude	: 44.977,
		OffsetUTC	: -6,
		DLSrule	: 'US'
	},
	{
		Name		: {en: 'New York', ja: 'ニューヨーク', fr: 'New York'},
		longitude	: -73,
		latitude	: 41,
		OffsetUTC	: -5,
		DLSrule	: 'US'
	},
	{
		Name		: {en: 'Buenos-Aires', ja: 'ブエノスアイレス', fr: 'Buenos-Aires'},
		longitude	: -58.147,
		latitude	: -34.612,
		OffsetUTC	: -4,
		DLSrule	: '0'
	},
	{
		Name		: {en: 'London', ja: 'ロンドン', fr: 'Londres'},
		longitude	: -0.126,
		latitude	: 51.500,
		LiftLabel	: true,
		OffsetUTC	: 0,
		DLSrule	: 'EU'
	},
	{
		Name		: {en: 'Paris', ja: 'パリ', fr: 'Paris'},
		longitude	: 2.351,
		latitude	: 48.857,
		OffsetUTC	: 1,
		DLSrule	: 'EU'
	},
	{
		Name		: {en: 'Moscow', ja: 'モスクワ', fr: 'Moscou'},
		longitude	: 37.618,
		latitude	: 55.756,
		OffsetUTC	: 3,
		DLSrule	: '0'
	},
	{
		Name		: {en: 'Beijing', ja: '北京', fr: 'P&eacute;kin'},
		longitude	: 116.398,
		latitude	: 39.908,
		OffsetUTC	: 8,
		DLSrule	: '0'
	},
	{
		Name		: {en: 'Tokyo', ja: '東京', fr: 'Tokyo' },
		longitude	: 139.682,
		latitude	: 35.678,
		OffsetUTC	: 9,
		DLSrule	: '0'
	},
	{
		Name		: {en: 'Sydney', ja: 'シドニー', fr: 'Sydney'},
		longitude	: 151.207,
		latitude	: -33.867,
		OffsetUTC	: 10,
		DLSrule	: 'AN'
	},
	{
		Name		: {en: "N'Djamena", ja: 'ンジャメナ', fr: "N'Djaména"},
		longitude	: 15.03,
		latitude	: 12.07,
		OffsetUTC	: 1,
		DLSrule	: '0'
	}
];

/*
 * TimeFormat Clock format for each locale.
 *
 * 24 = 24 hour format, others 12 hour with AM/PM
 */
var TimeFormat =
{
	en: 24,  
	ja: 24,  
	fr: 24
};

/*
 * DLSrules Array of Daylight Saving Time mode.
 *
 * ID      ID for the mode.
 * Start   DST start (Month, WeekNumber, WeekDay, Hours)
 * End     DST end   (Month, WeekNumber, WeekDay, Hours)
 *		Month (1 ~ 12)
 *		Date(0 or 1 ~ 31)
 *		WeekDay after this date (-1 = Last Week, 1~ )
 *		WeekDay (0 = Sunday ~ 6 = Saturday)
 *		Hours (0 ~ 23 Change at this time of standard time.)
 *		     if start character is 'u', it's UTC.
 *		if Date is 0, WeekDay value is valid.
 *		The folllowing Data is referrd http://home.tiscali.nl/~t876506/TZworld.html
 */
var DLSrules =
[
	//	EU
	{
		ID		: 'EU',
		Start	: '3, 0, -1, 0, u1',
		End		: '10, 0, -1, 0, u1'
	},
	//	Thule
	{
		ID		: 'Thule',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 1'
	},
	//	EUAsia
	{
		ID		: 'EUAsia',
		Start	: '3, 0, -1, 0, 1',
		End		: '10, 0, -1, 0, 1'
	},
	//	Russia 2011年に廃止
/*
	{
		ID		: 'Russia',
		Start	: '3, 0, -1, 0, 2',
		End		: '10, 0, -1, 0, 2'
	},
	//	RussiaAsia
	{
		ID		: 'RussiaAsia',
		Start	: '3, 0, -1, 0, 2',
		End		: '10, 0, -1, 0, 2'
	},
*/
	//	Azer
	{
		ID		: 'Azer',
		Start	: '3, 0, -1, 0, 4',
		End		: '10, 0, -1, 0, 4'
	},
	{
	//	US
		ID		: 'US',
		Start	: '3, 0, 8, 0, 2',
		End		: '11, 0, 1, 0, 3'
	},
	//	Canada
	{
		ID		: 'Canada',
		Start	: '3, 0, 8, 0, 2',
		End		: '11, 0, 1, 0, 3'
	},
	//StJohns (Not Correct Data)
	//Start at 0:01 of Local Time, End at 0:01 of Local Time
	{
		ID		: 'StJohns',
		Start	: '3, 0, 8, 0, 0',
		End		: '11, 0, 1, 0, 0'
	},
	//Winn
	{
		ID		: 'Winn',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 2'
	},
	//	Edm
	{
		ID		: 'Edm',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 3'
	},
	//	Vanc
	{
		ID		: 'Vanc',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 3'
	},
	//	NT_YK
	{
		ID		: 'NT_YK',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 3'
	},
	//	Bahamas
	{
		ID		: 'Bahamas',
		Start	: '3, 0, 8, 0, 2',
		End		: '11, 0, 1, 0, 3'
	},
	//	Cuba
	{
		ID		: 'Cuba',
		Start	: '4, 0, 1, 0, 0',
		End		: '10, 0, -1, 0, 0'
	},
	//	Mexico
	{
		ID		: 'Mexico',
		Start	: '4, 0, 1, 0, 2',
		End		: '10, 0, -1, 0, 3'
	},
	//	TC
	{
		ID		: 'TC',
		Start	: '3, 0, 8, 0, 2',
		End		: '11, 0, 1, 0, 1'
	},
	//	Brazil
	{
		ID		: 'Brazil',
		Start	: '11, 5, 0, 0, 0',
		End		: '2, 24, 0, 0, 23'
	},
	//	Chile
	{
		ID		: 'Chile',
		Start	: '10, 0, 9, 0, u4',
		End		: '3, 0, 9, 0, u3'
	},
	//	Falk
	{
		ID		: 'Falk',
		Start	: '9, 0, 1, 0, 2',
		End		: '4, 0, 15, 0, 1'
	},
	//	Para
	{
		ID		: 'Para',
		Start	: '10, 0, 15, 0, 0',
		End		: '3, 0, 7, 6, 23'
	},
	//	Uruguay
	{
		ID		: 'Uruguay',
		Start	: '10, 0, 1, 0, 2',
		End		: '3, 0, 8, 0, 1'
	},
	//	Iraq
	{
		ID		: 'Iraq',
		Start	: '4, 1, 0, 0, 3',
		End		: '10, 1, 0, 0, 3'
	},
	//	Zion
	//DST on: find in our calculator: first Friday of April on/before day 1. This will also get the correct Friday if it is in March.
	//DST off: find Tishrei 10 in the Hebrew calendar, find the corresponding Gregorian date and trace backwards to the first Sunday 02:00h.
	{
		ID		: 'Zion',
		Start	: '3, 0, 26, 5, 2',
		End		: '9, 27, 0, 0, 1'
	},
	//	Jordan
	{
		ID		: 'Jordan',
		Start	: '3, 0, -1, 4, 0',
		End		: '10, 0, -1, 5, 0'
	},
	//	Lebanon
	{
		ID		: 'Lebanon',
		Start	: '3, 0, -1, 0, 0',
		End		: '10, 0, 24, 6, 23'
	},
	//	Palestine
	{
		ID		: 'Palestine',
		Start	: '4, 1, 0, 0, 0',
		End		: '10, 0, 14, 4, 23'
	},
	//	Syria
	{
		ID		: 'Syria',
		Start	: '3, 0, -1, 5, 0',
		End		: '10, 1, 0, 0, 0'
	},
	//	Syria
	{
		ID		: 'Syria',
		Start	: '3, 0, -1, 5, 0',
		End		: '9, 30, 0, 0, 23'
	},
	//	AN
	{
		ID		: 'AN',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 2'
	},
	//	AS
	{
		ID		: 'AS',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 2'
	},
	//	AT
	{
		ID		: 'AT',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 2'
	},
	//	AV
	{
		ID		: 'AV',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 2'
	},
	//	AW
	//***** Trial 2007 - 2009 *****
	{
		ID		: 'AW',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 2'
	},
	//	LH
	{
		ID		: 'LH',
		Start	: '10, 0, -1, 0, 2',
		End		: '3, 0, -1, 0, 1'
	},
	//	NZ
	{
		ID		: 'NZ',
		Start	: '9, 0, -1, 0, 2',
		End		: '4, 0, 1, 0, 2'
	},
	//	Chatham
	{
		ID		: 'Chatham',
		Start	: '9, 0, -1, 0, 2.75',
		End		: '4, 0, 1, 0, 2.75'
	},
	//	Egypt
	{
		ID		: 'Egypt',
		Start	: '4, 0, -1, 5, 0',
		End		: '9, 0, -1, 4, 23'
	},
	//	Namibia
	{
		ID		: 'Namibia',
		Start	: '9, 0, 1, 0, 2',
		End		: '4, 0, 1, 0, 1'
	},
	//	ChileAQ
	{
		ID		: 'ChileAQ',
		Start	: '10, 0, 9, 0, 0',
		End		: '3, 0, 8, 6, 23'
	},
	//	NZAQ
	{
		ID		: 'NZAQ',
		Start	: '10, 0, 1, 0, 2',
		End		: '3, 0, 15, 0, 2'
	},
]
